@@ -18,12 +18,8 @@
 #
 
 import logging
-import os.path
-import sanlock
 
-from ..agent import constants as agent_constants
 from ..env import config
-from ..env import constants
 from ..lib import brokerlink
 from ..lib import metadata
 from ..lib import storage_server
@@ -61,7 +57,7 @@ class HAClient(object):
         LOCAL = 'LOCAL'
         GLOBAL = 'GLOBAL'
 
-    def __init__(self, log=False, retries=1, wait=0):
+    def __init__(self, log=False, **kwargs):
         """
         Create an instance of HAClient.  If the caller has a log handler, it
         should pass in log=True, else logging will effectively be disabled.
@@ -71,16 +67,11 @@ class HAClient(object):
                                 level=logging.CRITICAL)
         self._log = logging.getLogger("%s.HAClient" % __name__)
         self._config = None
-        self._retries = retries
-        self._wait = wait
 
     def _check_liveness_metadata(self, md, broker):
-        with broker.connection(self._retries, self._wait):
-            self._configure_broker_conn(broker)
-            service = constants.SERVICE_TYPE + agent_constants.MD_EXTENSION
-            md["live-data"] = broker.is_host_alive(service, md["host-id"])
-            self._log.debug("Is host '{0}' alive? -> '{1}'"
-                            .format(md["host-id"], md["live-data"]))
+        md["live-data"] = broker.is_host_alive(md["host-id"])
+        self._log.debug("Is host '{0}' alive? -> '{1}'"
+                        .format(md["host-id"], md["live-data"]))
 
         return md["live-data"]
 
@@ -99,10 +90,7 @@ class HAClient(object):
         if self._config is None:
             self._config = config.Config()
         broker = brokerlink.BrokerLink()
-        with broker.connection(self._retries, self._wait):
-            self._configure_broker_conn(broker)
-            service = constants.SERVICE_TYPE + agent_constants.MD_EXTENSION
-            stats = broker.get_stats_from_storage(service)
+        stats = broker.get_stats_from_storage()
 
         stats = self._parse_stats(stats, mode)
         self._check_liveness_for_stats(stats, broker)
@@ -119,7 +107,7 @@ class HAClient(object):
         sb = storage_broker.StorageBroker()
         sb.set_storage_domain("client", StorageBackendTypes.FilesystemBackend,
                               sd_uuid=sd_uuid, dom_type=dom_type)
-        stats = sb.get_raw_stats_for_service_type("client", service_type)
+        stats = sb.get_raw_stats("client", service_type)
 
         return self._parse_stats(stats, mode)
 
@@ -170,15 +158,6 @@ class HAClient(object):
             service_type,
             self.StatModes.HOST)
 
-    def _configure_broker_conn(self, broker):
-        if self._config is None:
-            self._config = config.Config()
-        sd_uuid = self._config.get(config.ENGINE, config.SD_UUID)
-        dom_type = self._config.get(config.ENGINE, config.DOMAIN_TYPE)
-        broker.set_storage_domain(StorageBackendTypes.FilesystemBackend,
-                                  sd_uuid=sd_uuid,
-                                  dom_type=dom_type)
-
     def set_global_md_flag(self, flag, value):
         """
         Connects to HA broker and sets flags in global metadata, leaving
@@ -198,28 +177,22 @@ class HAClient(object):
             put_val = value
 
         broker = brokerlink.BrokerLink()
-        with broker.connection(self._retries, self._wait):
-            self._configure_broker_conn(broker)
-            service = constants.SERVICE_TYPE + agent_constants.MD_EXTENSION
-            all_stats = broker.get_stats_from_storage(service)
+        all_stats = broker.get_stats_from_storage()
 
-            global_stats = all_stats.get(0)
-            if global_stats and len(global_stats):
-                try:
-                    md_dict = metadata.parse_global_metadata_to_dict(
-                        self._log, global_stats)
-                except Exception:
-                    self._log.warn("Metadata block corrupted. Correcting.")
-                    md_dict = {}
-            else:
+        global_stats = all_stats.get(0)
+        if global_stats and len(global_stats):
+            try:
+                md_dict = metadata.parse_global_metadata_to_dict(
+                    self._log, global_stats)
+            except Exception:
+                self._log.warn("Metadata block corrupted. Correcting.")
                 md_dict = {}
+        else:
+            md_dict = {}
 
-            md_dict[flag] = put_val
-            block = metadata.create_global_metadata_from_dict(md_dict)
-            broker.put_stats_on_storage(
-                constants.SERVICE_TYPE + agent_constants.MD_EXTENSION,
-                0,
-                block)
+        md_dict[flag] = put_val
+        block = metadata.create_global_metadata_from_dict(md_dict)
+        broker.put_stats_on_storage(0, block)
 
     def get_local_host_id(self):
         if self._config is None:
@@ -234,10 +207,7 @@ class HAClient(object):
 
         host_id = int(self._config.get(config.ENGINE, config.HOST_ID))
         broker = brokerlink.BrokerLink()
-        with broker.connection(self._retries, self._wait):
-            self._configure_broker_conn(broker)
-            service = constants.SERVICE_TYPE + agent_constants.MD_EXTENSION
-            stats = broker.get_stats_from_storage(service)
+        stats = broker.get_stats_from_storage()
 
         score = 0
         if host_id in stats:
@@ -284,15 +254,6 @@ class HAClient(object):
         return self._config.get_all_shared_keys(config_type)
 
     def reset_lockspace(self, force=False):
-        # Lockspace file
-        lockspace_file = None
-
-        # Service names
-        lockspace = (constants.SERVICE_TYPE +
-                     agent_constants.LOCKSPACE_EXTENSION)
-        service = (constants.SERVICE_TYPE +
-                   agent_constants.MD_EXTENSION)
-
         if self._config is None:
             self._config = config.Config()
 
@@ -306,10 +267,7 @@ class HAClient(object):
         # Connect to a broker and read all stats
         broker = brokerlink.BrokerLink()
 
-        with broker.connection():
-            self._configure_broker_conn(broker)
-            stats = broker.get_stats_from_storage(service)
-            lockspace_file = broker.get_service_path(lockspace)
+        stats = broker.get_stats_from_storage()
 
         # Process raw stats
         try:
@@ -331,10 +289,7 @@ class HAClient(object):
                     raise Exception("Lockfile reset cannot be performed with"
                                     " an active agent.")
 
-        if os.path.exists(lockspace_file):
-            sanlock.write_lockspace(lockspace=constants.SERVICE_TYPE,
-                                    path=lockspace_file,
-                                    offset=0)
+        broker.reset_lockspace()
 
     def connect_storage_server(self):
         sserver = storage_server.StorageServer()
